//-----------------------------------------------
// Add/Delete Physical Config methods
//-----------------------------------------------
var addPhysConfHandler = function(){
  alert("Feature not yet supported!");
};

function addConfig(){
  var form = addPhysConfForm.getForm();
  var el  = form.getEl();

  el.dom.action = "config/addPhysicalConfigFromEditor";
  el.dom.method = 'POST';
  form.submit({
    success: function(){
      addPhysConfWindow.hide();
      //Ext.Msg.alert("Added config successfully!","Please configure the new configuration!");
      reloadTree(true);
    },
    failure: Paraxip.failureMessage
  });
};

function removePhysConfig(){
  var selectedRecords = gridPhysicalConfig.getSelectionModel().getSelections();

  if (selectedRecords !== []) {
    if ( gridPhysicalConfig.store.getCount() - selectedRecords.length < 1 ){
      Ext.Msg.alert("Can not delete last config!",
        "At least one config is necessary for the system to work properly. " +
        "Please edit current config or create a new one before deleting " +
        "this one");
    } else {
      var physConfigs = new Array();
      for (var i = 0; i < selectedRecords.length; i++) {
        physConfigs.push(selectedRecords[i].data);
      }
      physConfigs = Ext.util.JSON.encode(physConfigs);
      Ext.Ajax.request({
        url: 'config/deletePhysicalConfigFromEditor',
        method: 'POST',
        disableCaching: false,
        params: {"physConfigs":physConfigs},
        success: function ()
        {
          for (var index = 0; index < selectedRecords.length; index++) {
            gridPhysicalConfig.store.remove(selectedRecords[index]);
          }
          reloadTree(true);
        },
        failure: Paraxip.failureMessage
      });
    }
  }
};

var physConfTypeComboBox = new Ext.form.ComboBox({
  id              : 'configType',
  fieldLabel      : "Physical Config Type",
  store           : ['T1','E1','Analog'],
  helpText        : "pstnConfigphysicalInterfaceConfigs",
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  value           : 'T1',
  selectOnFocus   : true,
  width           : 100
});

var addPhysConfForm = new Ext.form.FormPanel({
  labelWidth  : 175,
  labelPad    : 10,
  region      : "center",
  bodyStyle   : 'padding:10px;',
  frame       : false,
  header      : false,
  footer      : false,
  id          : "addPhysConfForm",
  buttonAlign : "right",
  buttons     : [{
    text: "Add",
    listeners: {'click':addConfig}
  },{
    text: "Cancel",
    listeners: {'click':function(){addPhysConfWindow.hide();}}
  }]
});

var addPhysConfWindow = new Ext.Window({
  title       : 'Add Physical Config Window',
  layout      : 'border',
  width       : 505,
  height      : 150,
  closeAction : 'hide',
  plain       : true,
  id          : "addPhysConfWindow"
});

addPhysConfForm.add(physConfTypeComboBox);
addPhysConfWindow.add(addPhysConfForm);

var gridPhysicalConfig = new Ext.grid.GridPanel({
  title       : 'Physical Configurations Grid',
  id          : 'gridPhysicalConfig',
  autoScroll  : true,
  layout      : 'absolute',
  store       : new Ext.data.JsonStore({
    id:'storePhysicalConfig',
    url: 'config/getGridPhysicalConfigData',
    root: 'data',
    fields: [
      {name: 'id'}, //Not displayed
      {name: 'displayName'},
      {name: 'nodeId'} //Not displayed
    ]
  }),
  columns     :[
    {header: "ID", width: 35, sortable: true, dataIndex: 'id',
      css:'padding:5px;'},
    {header: "Name", width: 200, sortable: true, dataIndex: 'displayName',
      css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}
});

gridPhysicalConfig.addButton("Add Physical Config",
                             function(){addPhysConfWindow.show();});
gridPhysicalConfig.addButton("Remove Physical Config",removePhysConfig);

gridPhysicalConfig.on('rowdblclick', function(grid, rowIndex){
  var record = grid.store.getAt(rowIndex);
  goToNode(record.get('nodeId'));
});

//gridPhysicalConfig.store.on({
//    'load':{
//        fn: function(store, records, options){
//          //store is loaded, now you can work with it's records, etc.
//          Paraxip.console.debug('store load, arguments:', arguments);
//          Paraxip.console.debug('Store count = ', store.getCount());
//        },
//        scope:this
//    },
//    'loadexception':{
//        //consult the API for the proxy used for the actual arguments
//        fn: function(obj, options, response, e){
//          Paraxip.console.debug('store loadexception, arguments:', arguments);
//          Paraxip.console.debug('error = ', e);
//        },
//        scope:this
//    }
//});

//------------------------------------------------
// Factory to create common fields between forms
//------------------------------------------------

/**************************
  AUDIO Configuration
***************************/

function createAudioLabel(){
  return new Ext.form.Label(Ext.apply({
    text  : "Audio Configuration",
    style : 'line-height:40px;'
  }));
};

function createPcmLawSelection(config){
  return new Ext.form.ComboBox( Ext.apply({
    fieldLabel      : "Default PCM law",
    name            : 'defaultPcmLaw',
    store           : ['PCMU','PCMA'],
    helpText        : "audioParametersaudiodefaultPcmLaw",
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  }, config));
};

// Max is 30 ms and Min is 10 ms
function createVoicePacketText(config){
  return new Ext.form.TextField( Ext.apply({
    fieldLabel  : "Voice packet length (ms)",
    name        : 'voicePacketLengthInMs',
    helpText    : "audioParametersaudiovoicePacketLengthInMs",
    width       : 162
  }, config));
};

function createToneSetAtributesSelection(config){
  return new Ext.form.ComboBox( Ext.apply({
    name            : 'toneSetName',
    fieldLabel      : "Tone Set Attributes",
    helpText        : 'toneSetAttributestoneSetName',
    store           : ['canada','us','uk','australia'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  }, config));
};


/********************************
  EchoCancellation Configuration
*********************************/

function createEchoCancelLabel(){
  return new Ext.form.Label(Ext.apply({
    text     : "Echo Cancellation",
    style    : 'line-height:40px;'
  }));
};

function createEcTypeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'type',
    fieldLabel      : "Type",
    helpText        : "HardwareEchoCancellationEchoCancellation",
    store           : ['HARDWARE'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createEcModeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'mode',
    fieldLabel      : "Mode",
    helpText        : "HardwareEchoCancellationEchoCancellationmode",
    store           : ['NORMAL','SPEECH_RECOGNIZER_FRIENDLY','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 200
  },config));
};

function createEcComfortNoiseSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'comfortNoiseMode',
    fieldLabel      : "Comfort Noise Mode",
    store           : ['NORMAL','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

// Max 896 Min 0
function createEcTailText(config){
  return new Ext.form.TextField(Ext.apply({
    name        : 'tailDisplacementInMs',
    fieldLabel  : "Tail Displacement (ms)",
    width       : 162
  },config));
};

function createEcDoubleTalkSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'doubleTalkBehavior',
    fieldLabel      : "Double Talk Behavior",
    store           : ['OPTIMAL','MORE_RESIDUAL_ECHO','MORE_CLIPPING'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

/****************************************
  AcousticEchoCancellation Configuration
*****************************************/

function createAcousticLabel(){
  return new Ext.form.Label(Ext.apply({
    text: "Acoustic Echo Cancellation",
    style: 'line-height:40px;'
  }));
};

function createAecTypeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'type',
    fieldLabel      : "Type",
    store           : ['HARDWARE'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createAecModeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'mode',
    fieldLabel      : "Mode",
    store           : ['NORMAL','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

/***************************************
  LevelControl Configuration
****************************************/

function createLevelControlLabel(){
  return new Ext.form.Label(Ext.apply({
    text: "Level Control",
    style: 'line-height:40px;'
  }));
};

function createLevelTypeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'type',
    fieldLabel      : "Type",
    store           : ['HARDWARE'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createLevelDirectionSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'direction',
    fieldLabel      : "Direction",
    store           : ['ALL','TO_PSTN','FROM_PSTN'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createLevelModeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'mode',
    fieldLabel      : "Mode",
    store           : ['MANUAL','AUTOMATIC','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

// Max 0 Min -40
function createLevelTargetText(config){
  return new Ext.form.TextField(Ext.apply({
    name        : 'targetLevelIndBM0',
    fieldLabel  : "Target Level In dBM0",
    allowBlank  : false,
    width       : 162
  },config));
};

// Max 24 Min -24
function createLevelGainText(config){
  return new Ext.form.TextField(Ext.apply({
    name        : 'gainIndB',
    fieldLabel  : "Gain In dB",
    width       : 162,
    allowBlank  : false,
    blankText   : "This field can not be empty"
  },config));
};

/****************************************************
  BackgroundNoiseAttenuation Configuration
*****************************************************/

function createBackgroundLabel(){
  return new Ext.form.Label(Ext.apply({
    text: "Background Noise Attenuation",
    style: 'line-height:40px;'
  }));
};

function createBnaTypeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'type',
    fieldLabel      : "Type",
    store           : ['HARDWARE'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createBnaDirectionSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'direction',
    fieldLabel      : "Direction",
    store           : ['ALL','TO_PSTN','FROM_PSTN'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createBnaModeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'mode',
    fieldLabel      : "Mode",
    store           : ['ENABLED','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createBnaAttenuationSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'attenuationIndB',
    fieldLabel      : "Attenuation In dB",
    store           : ['-9','-12','-15','-18','-21','-24','-27','-30'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

/****************************************************
  DTMFRemoval Configuration
*****************************************************/

function createDTMFRemovalLabel(){
  return new Ext.form.Label(Ext.apply({
    text: "DTMF Removal",
    style: 'line-height:40px;'
  }));
};

function createDtmfTypeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'type',
    fieldLabel      : "Type",
    store           : ['HARDWARE'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createDtmfDirectionSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'direction',
    fieldLabel      : "Direction",
    store           : ['FROM_PSTN'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

function createDtmfModeSelect(config){
  return new Ext.form.ComboBox(Ext.apply({
    name            : 'mode',
    fieldLabel      : "Mode",
    store           : ['ENABLED','DISABLED'],
    forceSelection  : true,
    triggerAction   : 'all',
    mode            : 'local',
    typeAhead       : true,
    selectOnFocus   : true,
    width           : 145,
    minListWidth    : 145
  },config));
};

//------------------------------------------------
// Common methods
//------------------------------------------------
function saveConfig(e){
  //e is the button clicked. To get the form, pass by its owner
  var owner = e.ownerCt;
  var form = owner.getForm();
  var el = form.getEl();

  el.dom.action = 'config/savePhysicalConf';
  el.dom.method = 'POST';

  // getItemsValueAsJson is a Ext.Container override
  var physicalConfig = owner.getItemsValueAsJson();

  form.submit({
    params:{
      'physicalConfig': physicalConfig
    },
    success: function(){
      reloadTree(true);
    },
    failure: Paraxip.failureMessage
  });
};

function physConfCancel(){
  reloadTree(true);
};

/*
 * This method is used to show/hide the gainIndB and the targetLevelIndBMO fields
 * of the Physical Config forms according to the LevelControl/Mode attribute.
 * If mode is automatic, hide the field; if it's true, show the field.
 */
function levelControlVisibleFields(){
  var levelMode;
  var levelGain;
  var levelTargetIndBMO;

  if( this.id == "frmDigitalT1PhysConf" ) {
    levelMode = levelT1_mode_select;
    levelGain = levelT1_gainIndB_text;
    levelTargetIndBMO = levelT1_targetLevelIndBM0_text;
  } else if( this.id == "frmDigitalE1PhysConf" ) {
    levelMode = levelE1_mode_select;
    levelGain = levelE1_gainIndB_text;
    levelTargetIndBMO = levelE1_targetLevelIndBM0_text;
  } else if( this.id == "frmAnalogPhysConf" ) {
    levelMode = levelAnalog_mode_select;
    levelGain = levelAnalog_gainIndB_text;
    levelTargetIndBMO = levelAnalog_targetLevelIndBM0_text;
  } else {
    Paraxip.console.Error("The formPanel with id [%s] is unknown" % this.id);
    return;
  }
  if( levelMode.getValue() == "AUTOMATIC") {
    //levelGain.hide();
    //levelGain.getEl().up('.x-form-item').setDisplayed(false); //show label
    levelGain.disable();
    levelGain.clearInvalid();
    levelTargetIndBMO.enable();
  } else if( levelMode.getValue() == "MANUAL") {
    //levelGain.show();
    //levelGain.getEl().up('.x-form-item').setDisplayed(true); //show label
    levelGain.enable();
    levelTargetIndBMO.disable();
    levelTargetIndBMO.clearInvalid();
  } else if( levelMode.getValue() == "DISABLED") {
    levelGain.disable();
    levelGain.clearInvalid();
    levelTargetIndBMO.disable();
    levelTargetIndBMO.clearInvalid();
  }
};

function isDChannelEnabled(){
  var channelIndexText;
  var mtuText;

  if( this.getId() == "disableDChannelT1" ) {
    channelIndexText = channelT1_idx_text;
    mtuText = mtu_sizeT1_text;
  } else if( this.getId() == "disableDChannelE1" ) {
    channelIndexText = channelE1_idx_text;
    mtuText = mtu_sizeE1_text;
  }

  if( this.getValue() == "DISABLED" ) {
    channelIndexText.setContainerVisible(false);
    mtuText.setContainerVisible(false);
  } else if( this.getValue() == "ENABLED" ) {
    channelIndexText.setContainerVisible(true);
    channelIndexText.disable();
    mtuText.setContainerVisible(true);
  }
};
//------------------------------------------------
// Apply_To forms and methods
//------------------------------------------------
function applyToConfig(e){
  var form = e.ownerCt;
  var url;
  var gridData;
  var records;
  var i;

  if( form.id == "assignBoardsWindow") {
    url = "config/applyBoardsToConfig";
    records = assignedBoardsGrid.getStore().getRange();
    gridData = new Array();
    for (i = 0; i < records.length; i++) {
      gridData.push(records[i].data);
    }
    gridData = Ext.util.JSON.encode(gridData);
  } else if( form.id == "assignInterfacesWindow") {
    url = "config/applyInterfacesToConfig";
    records = assignedInterfacesGrid.getStore().getRange();
    gridData = new Array();
    for (i = 0; i < records.length; i++) {
      gridData.push(records[i].data);
    }
    gridData = Ext.util.JSON.encode(gridData);
  }

  Ext.Ajax.request({
    url: url,
    method: 'POST',
    disableCaching: false,
    params: {'gridData':gridData,'configID':Ext.util.JSON.encode(configId)},
    success: function(){
      form.hide();
      //reloadTree(true);
    },
    failure: Paraxip.failureMessage
  });

};

function addToGrid(e){
  var grid; //unassigned grid
  var assignedGrid;
  var i;

  if( e.id == "assignBoardButton" ) {
    grid = unassignedBoardsGrid;
    assignedGrid = assignedBoardsGrid;
  } else if( e.id == "assignInterfaceButton") {
    grid = unassignedInterfacesGrid;
    assignedGrid = assignedInterfacesGrid;
  }
  var selectedRecords = grid.getSelectionModel().getSelections();

  if (selectedRecords !== []) {
    assignedGrid.getStore().add(selectedRecords);
    for( i = 0; i < selectedRecords.length; i++ ) {
      grid.getStore().remove(selectedRecords[i]);
    }
  }

};

function removeFromGrid(e){
  var grid; //assigned grid
  var unassignedGrid;
  var i;

  if( e.id == "unassignBoardButton" ) {
    grid = assignedBoardsGrid;
    unassignedGrid = unassignedBoardsGrid;
  } else if( e.id == "unassignInterfaceButton") {
    grid = assignedInterfacesGrid;
    unassignedGrid = unassignedInterfacesGrid;
  }

  var selectedRecords = grid.getSelectionModel().getSelections();

  if (selectedRecords !== []) {
    unassignedGrid.getStore().add(selectedRecords);
    for( i = 0; i < selectedRecords.length; i++ ) {
      grid.getStore().remove(selectedRecords[i]);
    }
  }

};

//Analog configs
var configId = "";

var assignBoardsWindow = new Ext.Window({
  title       : 'Assign Boards To Config',
  layout      : 'border',
  width       : 600,
  height      : 500,
  closeAction : 'hide',
  resizable   : false,
  plain       : true,
  id          : "assignBoardsWindow",
  buttonAlign : "right",
  buttons     : [{
    text: "Save",
    listeners: {'click':applyToConfig}
  },{
    text: "Cancel",
    listeners: {'click':function(){assignBoardsWindow.hide();}}
  }]
});

var assignBoardsForm = new Ext.FormPanel({
  region      : "center",
  id          : "assignBoardsForm",
  items       : [{
    xtype:'button',
    style: 'margin:auto;position: relative;top:200px;',
    id: 'assignBoardButton',
    text: '->',
    listeners: {'click':addToGrid}
  },{
    xtype:'button',
    style: 'margin:auto;position: relative;top:200px;',
    id: 'unassignBoardButton',
    text: '<-',
    listeners: {'click':removeFromGrid}
  }]
});

var unassignedBoardsGrid = new Ext.grid.GridPanel({
  title       : 'Unassigned Board(s)',
  id          : 'unassignedBoardsGrid',
  autoScroll  : true,
  region      : "west",
  width       : 270,
  store       : new Ext.data.JsonStore({
    id:'storeUnassignedBoards',
    url: 'config/getUnassignedBoards',
    root: 'data',
    fields: [
      {name: 'id'},
      {name: 'displayName'}
    ]
  }),
  columns     :[
    {header: "ID", width: 35, sortable: true, dataIndex: 'id',
      css:'padding:5px;'},
    {header: "Board Name", width: 200, sortable: true, dataIndex: 'displayName',
      css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}

});

var assignedBoardsGrid = new Ext.grid.GridPanel({
  title       : 'Assigned Board(s)',
  id          : 'assignedBoardsGrid',
  region      : "east",
  autoScroll  : true,
  width       : 270,
  store       : new Ext.data.JsonStore({
    id:'storeAssignedBoards',
    url: 'config/getAssignedBoards',
    root: 'data',
    fields: [
      {name: 'id'},
      {name: 'displayName'}
    ]
  }),
  columns     :[
    {header: "ID", width: 35, sortable: true, dataIndex: 'id',
      css:'padding:5px;'},
    {header: "Board Name", width: 200, sortable: true, dataIndex: 'displayName',
      css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}

});
assignBoardsWindow.add(assignBoardsForm);
assignBoardsWindow.add(assignedBoardsGrid);
assignBoardsWindow.add(unassignedBoardsGrid);

//Digital configs
var assignInterfacesWindow = new Ext.Window({
  title       : 'Assign Interfaces To Config',
  layout      : 'border',
  width       : 750,
  height      : 500,
  closeAction : 'hide',
  resizable   : false,
  plain       : true,
  id          : "assignInterfacesWindow",
  buttonAlign : "right",
  buttons     : [{
    text: "Save",
    listeners: {'click':applyToConfig}
  },{
    text: "Cancel",
    listeners: {'click':function(){assignInterfacesWindow.hide();}}
  }]
});

var assignInterfacesForm = new Ext.Panel({
  labelWidth  : 175,
  labelPad    : 10,
  region      : "center",
  frame       : false,
  header      : false,
  footer      : false,
  id          : "assignInterfacesForm",
  items       : [{
    xtype:'button',
    style: 'margin:auto;position: relative;top:200px;',
    id: 'assignInterfaceButton',
    text: '->',
    listeners: {'click':addToGrid}
  },{
    xtype:'button',
    style: 'margin:auto;position: relative;top:200px;',
    id: 'unassignInterfaceButton',
    text: '<-',
    listeners: {'click':removeFromGrid}
  }]
});

var unassignedInterfacesGrid = new Ext.grid.GridPanel({
  title       : 'Unassigned Interface(s)',
  id          : 'unassignedInterfacesGrid',
  region      : "west",
  autoScroll  : true,
  width       : 345,
  store       : new Ext.data.JsonStore({
    id:'storeUnassignedInterfaces',
    url: 'config/getUnassignedInterfaces',
    root: 'data',
    fields: [
      {name: 'displayName'},
      {name: 'boardID'},
      {name: 'ifName'},
      {name: 'id'}
    ]
  }),
  columns     :[
    {header: "Board Name", width: 130, sortable: true, dataIndex: 'displayName', css:'padding:5px;'},
    {header: "Board ID", width: 55, sortable: true, dataIndex: 'boardID', css:'padding:5px;'},
    {header: "Interface Name", width: 90, sortable: true, dataIndex: 'ifName', css:'padding:5px;'},
    {header: "Interface ID", width: 70, sortable: true, dataIndex: 'id', css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}
});

var assignedInterfacesGrid = new Ext.grid.GridPanel({
  title       : 'Assigned Interface(s)',
  id          : 'assignedInterfacesGrid',
  region      : "east",
  autoScroll  : true,
  width       : 345,
  store       : new Ext.data.JsonStore({
    id:'storeAssignedInterfaces',
    url: 'config/getAssignedInterfaces',
    root: 'data',
    fields: [
      {name: 'displayName'},
      {name: 'boardID'},
      {name: 'ifName'},
      {name: 'id'}
    ]
  }),
  columns     :[
    {header: "Board Name", width: 130, sortable: true, dataIndex: 'displayName', css:'padding:5px;'},
    {header: "Board ID", width: 55, sortable: true, dataIndex: 'boardID', css:'padding:5px;'},
    {header: "Interface Name", width: 90, sortable: true, dataIndex: 'ifName', css:'padding:5px;'},
    {header: "Interface ID", width: 70, sortable: true, dataIndex: 'id', css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}
});

assignInterfacesWindow.add(assignInterfacesForm);
assignInterfacesWindow.add(assignedInterfacesGrid);
assignInterfacesWindow.add(unassignedInterfacesGrid);

//------------------------------------------------
// Digital Physical T1 Config form
// -----------------------------------------------
var frmDigitalT1PhysConf = new Ext.FormPanel({
  title         : "Digital Physical Configuration",
  frame         : true,
  header        : false,
  id            : "frmDigitalT1PhysConf",
  autoScroll    : true,
  layout        : 'accordion',
  layoutConfig  : {
    activeItem  : 0
  },
  defaults      : {
    layout: 'form',
    style: 'text-align:left;',
    labelWidth: 150,
    bodyStyle: 'padding:5px;',
    width: 500,
    autoHeight: true,
    fill: true
  },
  buttonAlign   : "right",
  buttons       : [{
    text: 'Assigned interface(s)',
    listeners: {'click':function(){
        configId = id_textT1.getValue();
        unassignedInterfacesGrid.getStore().load({
           params: {'id':configId}
        });
        assignedInterfacesGrid.getStore().load({
           params: {'id':configId}
        });
        assignInterfacesWindow.show();
      }
    }
  },{
    text: 'Save',
    listeners: {'click':saveConfig}
  },{
    text: 'Cancel',
    listeners: {'click':physConfCancel}
  }]
});

var t1ConfigPanel = new Ext.Panel({
  id    : 't1ConfigPanel',
  name  : 'config',
  title : 'Configuration Info',
  items : [{
    xtype: 'textfield',
    id: 't1NodeId',
    name: 'nodeId',
    hidden: true,
    hideLabel: true
  }]
});

var digitalT1Panel = new Ext.Panel({
  id    : 'digitalT1Panel ',
  name  : 'digitalT1',
  title : 'Digital T1 Configuration'
});

var DChannelT1Panel = new Ext.Panel({
  id    : 'DChannelT1Panel ',
  name  : 'DChannelT1',
  title : 'DChannel T1 Configuration'
});

var audioT1Panel = new Ext.Panel({
  id    : 'audioT1Panel',
  name  : 'audio',
  title : 'Audio Configuration'
});

var echoT1Panel = new Ext.Panel({
  id    : 'echoT1Panel',
  name  : 'EchoCancellation',
  title : 'Echo Cancellation Configuration'
});

var acousticT1Panel = new Ext.Panel({
  id    : 'acousticT1Panel',
  name  : 'AcousticEchoCancellation',
  title : 'Acoustic Echo Cancellation Configuration'
});

var levelT1Panel = new Ext.Panel({
  id    : 'levelT1Panel',
  name  : 'LevelControl',
  title : 'Level Control Configuration'
});

var backgroundT1Panel = new Ext.Panel({
  id    : 'backgroundT1Panel',
  name  : 'BackgroundNoiseAttenuation',
  title : 'Background Noise Attenuation Configuration'
});

var dtmfT1Panel = new Ext.Panel({
  id    : 'dtmfT1Panel',
  name  : 'DTMFRemoval',
  title : 'DTMF Removal Configuration'
});

/**************************
  Digital T1 Configuration
***************************/

var id_textT1 = new Ext.form.TextField({
  id          : 'id_textT1',
  fieldLabel  : "ID",
  name        : "id",
  disabled    : true,
  width       : 162
});

var name_textT1 = new Ext.form.TextField({
  id          : 'name_textT1',
  fieldLabel  : "Display Name",
  name        : "displayName",
  width       : 162
});

var digitalT1_label = new Ext.form.Label({
  text  : "Digital T1 Physical Configuration",
  helpText : "t1ParametersdigitalT1",
  style : 'line-height:40px;'
});

var framingT1_select = new Ext.form.ComboBox({
  id              : 'framingT1_selection',
  name            : 'framing',
  fieldLabel      : "Framing",
  helpText        : "t1ParametersdigitalT1framing",
  store           : ['ESF','ESF_Japan','D4'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

var line_encT1_select = new Ext.form.ComboBox({
  id              : 'line_encT1_selection',
  name            : 'lineEncoding',
  fieldLabel      : "Line Encoding",
  helpText        : "t1ParametersdigitalT1lineEncoding",
  store           : ['AMI','B8ZS'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

var lboT1_select = new Ext.form.ComboBox({
  id              : 'lboT1_selection',
  name            : 'LBO',
  fieldLabel      : "LBO",
  helpText        : "t1ParametersdigitalT1LBO",
  store           : ['0dB','15dB','75dB','225B',
                     '0-110feet','110-220feet','220-330feet',
                     '330-440feet','440-550feet','550-660feet'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

var clockingT1_select = new Ext.form.ComboBox({
  id              : 'clockingT1_selection',
  name            : 'clocking',
  fieldLabel      : "Clocking",
  helpText        : "clockingclocking",
  store           : ['TERMINAL'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  disabled        : true,
  width           : 145,
  minListWidth    : 145
});
/*
var loopback_modeT1_select = new Ext.form.ComboBox({
  id              : 'loopback_modeT1_selection',
  name            : 'loopbackMode',
  fieldLabel      : "Loopback Mode",
  helpText        : "t1ParametersdigitalT1loopbackMode",
  store           : ['DISABLED'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});
*/
var dChannelT1_label = new Ext.form.Label({
  text: "D-Channel T1 Configuration",
  style: 'line-height:40px;'
});

var dChannelT1_disable = new Ext.form.ComboBox({
  id: 'disableDChannelT1',
  fieldLabel: 'Enable/Disable D-Channel',
  name: 'disableDChannel',
  store: ['ENABLED','DISABLED'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

dChannelT1_disable.on('select',isDChannelEnabled,dChannelT1_disable);

// Max value is 24 and Min is 1
var channelT1_idx_text = new Ext.form.TextField({
  id          : 'channelT1_idx_text',
  fieldLabel  : "D-Channel Index",
  name        : "channelIndex",
  helpText    : "t1ParametersdigitalT1DChannelT1channelIndex",
  disabled    : true,
  width       : 162,
  value       : 24
 /* validator  : function(txt){
                 var num = parseInt(txt);
                 if (num < 1) {
                  return "Minimum value for D-Channel index is 1";
                 }
                 if (num > 24) {
                  return "Maximum value for D-Channel index is 24";
                 }
                 return true;
               } */
});

// Max is 4096 and min 256
var mtu_sizeT1_text = new Ext.form.NumberField({
  id          : 'mtu_sizeT1_text',
  fieldLabel  : "MTU Size",
  name        : "mtuSize",
  helpText    : "DChannelMtuSizemtuSize",
  value       : 2048,
  width       : 162
});

mtu_sizeT1_text.on('render',function(){
  isDChannelEnabled.call(dChannelT1_disable);
});

var defaultPcmLawT1_select =  createPcmLawSelection({
  id    : 'defaultPcmLawT1_selection'
});

var voicePacketLengthInMsT1_text = createVoicePacketText({
  id  : 'voicePacketLengthInMsT1_text'
});

var toneSetAttributesT1_select = createToneSetAtributesSelection({
  id  : 'toneSetAttributesT1_select'
});

var ecT1_type_select = createEcTypeSelect({
  id  : 'ecT1_type_selection'
});

var ecT1_mode_select = createEcModeSelect({
  id  : 'ecT1_mode_selection'
});

var ecT1_comfortNoiseMode_select = createEcComfortNoiseSelect({
  id  : 'ecT1_comfortNoiseMode_selection'
});

var ecT1_tailDisplacementInMs_text = createEcTailText({
  id  : 'ecT1_tailDisplacementInMs_text'
});

var ecT1_doubleTalkBehavior_select = createEcDoubleTalkSelect({
  id  : 'ecT1_doubleTalkBehavior_selection'
});

var aecT1_type_select = createAecTypeSelect({
  id  : 'aecT1_type_selection'
});

var aecT1_mode_select = createAecModeSelect({
  id  : 'aecT1_mode_selection'
});

var levelT1_type_select = createLevelTypeSelect({
  id  : 'levelT1_type_selection'
});

var levelT1_direction_select = createLevelDirectionSelect({
  id  : 'levelT1_direction_selection'
});

var levelT1_mode_select = createLevelModeSelect({
  id        : 'levelT1_mode_selection',
  listeners : {
    'select': levelControlVisibleFields,
    scope   : frmDigitalT1PhysConf
      //function(){
//    if( this.getValue() == "AUTOMATIC") {
//      //levelT1_gainIndB_text.hide();
//      //levelT1_gainIndB_text.getEl().up('.x-form-item').setDisplayed(false); //show label
//      levelT1_gainIndB_text.disable();
//      levelT1_gainIndB_text.clearInvalid();
//    } else if( this.getValue() == "MANUAL") {
//      //levelT1_gainIndB_text.show();
//      //levelT1_gainIndB_text.getEl().up('.x-form-item').setDisplayed(true); //show label
//      levelT1_gainIndB_text.enable();
//    }
//  }
  }
});

var levelT1_targetLevelIndBM0_text = createLevelTargetText({
  id  : 'levelT1_targetLevelIndBM0_text'
});

var levelT1_gainIndB_text = createLevelGainText({
  id  : 'levelT1_gainIndB_text'
});

var bnaT1_type_select = createBnaTypeSelect({
  id  : 'bnaT1_type_selection'
});

var bnaT1_direction_select = createBnaDirectionSelect({
  id  : 'bnaT1_direction_selection'
});

var bnaT1_mode_select = createBnaModeSelect({
  id  : 'bnaT1_mode_selection'
});

var bnaT1_attenuationIndB_select = createBnaAttenuationSelect({
  id  : 'bnaT1_attenuationIndB_selection'
});

var dtmfT1_type_select = createDtmfTypeSelect({
  id  : 'dtmfT1_type_selection'
});

var dtmfT1_direction_select = createDtmfDirectionSelect({
  id  : 'dtmfT1_direction_selection'
});

var dtmfT1_mode_select = createDtmfModeSelect({
  id  : 'dtmfT1_mode_selection'
});

t1ConfigPanel.add(id_textT1);
t1ConfigPanel.add(name_textT1);
frmDigitalT1PhysConf.add(t1ConfigPanel);

//frmDigitalT1PhysConf.add(digitalT1_label);
digitalT1Panel.add(framingT1_select);
digitalT1Panel.add(line_encT1_select);
digitalT1Panel.add(lboT1_select);
digitalT1Panel.add(clockingT1_select);
//digitalT1Panel.add(loopback_modeT1_select);
frmDigitalT1PhysConf.add(digitalT1Panel);

//frmDigitalT1PhysConf.add(dChannelT1_label);
DChannelT1Panel.add(dChannelT1_disable);
DChannelT1Panel.add(channelT1_idx_text);
DChannelT1Panel.add(mtu_sizeT1_text);
frmDigitalT1PhysConf.add(DChannelT1Panel);

//frmDigitalT1PhysConf.add(createAudioLabel());
audioT1Panel.add(defaultPcmLawT1_select);
audioT1Panel.add(voicePacketLengthInMsT1_text);
audioT1Panel.add(toneSetAttributesT1_select);
frmDigitalT1PhysConf.add(audioT1Panel);

//frmDigitalT1PhysConf.add(createEchoCancelLabel());
echoT1Panel.add(ecT1_type_select);
echoT1Panel.add(ecT1_mode_select);
echoT1Panel.add(ecT1_comfortNoiseMode_select);
echoT1Panel.add(ecT1_tailDisplacementInMs_text);
echoT1Panel.add(ecT1_doubleTalkBehavior_select);
frmDigitalT1PhysConf.add(echoT1Panel);

//frmDigitalT1PhysConf.add(createAcousticLabel());
acousticT1Panel.add(aecT1_type_select);
acousticT1Panel.add(aecT1_mode_select);
frmDigitalT1PhysConf.add(acousticT1Panel);

//frmDigitalT1PhysConf.add(createLevelControlLabel());
levelT1Panel.add(levelT1_type_select);
levelT1Panel.add(levelT1_direction_select);
levelT1Panel.add(levelT1_mode_select);
levelT1Panel.add(levelT1_targetLevelIndBM0_text);
levelT1Panel.add(levelT1_gainIndB_text);
frmDigitalT1PhysConf.add(levelT1Panel);

//frmDigitalT1PhysConf.add(createBackgroundLabel());
backgroundT1Panel.add(bnaT1_type_select);
backgroundT1Panel.add(bnaT1_direction_select);
backgroundT1Panel.add(bnaT1_mode_select);
backgroundT1Panel.add(bnaT1_attenuationIndB_select);
frmDigitalT1PhysConf.add(backgroundT1Panel);

//frmDigitalT1PhysConf.add(createDTMFRemovalLabel());
dtmfT1Panel.add(dtmfT1_type_select);
dtmfT1Panel.add(dtmfT1_direction_select);
dtmfT1Panel.add(dtmfT1_mode_select);
frmDigitalT1PhysConf.add(dtmfT1Panel);

//-----------------------------------------------
// Digital Physical E1 Config form
// -----------------------------------------------
var frmDigitalE1PhysConf = new Ext.FormPanel({
  title           : "Digital Physical Configuration",
  frame           : true,
  header          : false,
  id              : "frmDigitalE1PhysConf",
  autoScroll      : true,
  layout        : 'accordion',
  layoutConfig  : {
    activeItem  : 0
  },
  defaults    : {
    layout: 'form',
    style: 'text-align:left;',
    labelWidth: 150,
    bodyStyle: 'padding:5px;',
    width: 500,
    autoHeight: true,
    fill: true
  },
  buttonAlign     : "right",
  buttons         : [{
    text: 'Assigned interface(s)',
    listeners: {'click':function(){
        configId = id_textE1.getValue();
        unassignedInterfacesGrid.getStore().load({
           params: {'id':configId}
        });
        assignedInterfacesGrid.getStore().load({
           params: {'id':configId}
        });
        assignInterfacesWindow.show();
      }
    }
  },{
    text: 'Save',
    listeners: {'click':saveConfig}
  },{
    text: 'Cancel',
    listeners: {'click':physConfCancel}
  }]
});

var e1ConfigPanel = new Ext.Panel({
  id    : 'e1ConfigPanel',
  name  : 'config',
  title : 'Configuration Info',
  items : [{
    xtype: 'textfield',
    id: 'e1NodeId',
    name: 'nodeId',
    hidden: true,
    hideLabel: true
  }]
});

var digitalE1Panel = new Ext.Panel({
  id    : 'digitalE1Panel ',
  name  : 'digitalE1',
  title : 'Digital E1 Configuration'
});

var DChannelE1Panel = new Ext.Panel({
  id    : 'DChannelE1Panel ',
  name  : 'DChannelE1',
  title : 'DChannel E1 Configuration'
});

var audioE1Panel = new Ext.Panel({
  id    : 'audioE1Panel',
  name  : 'audio',
  title : 'Audio Configuration'
});

var echoE1Panel = new Ext.Panel({
  id    : 'echoE1Panel',
  name  : 'EchoCancellation',
  title : 'Echo Cancellation Configuration'
});

var acousticE1Panel = new Ext.Panel({
  id    : 'acousticE1Panel',
  name  : 'AcousticEchoCancellation',
  title : 'Acoustic Echo Cancellation Configuration'
});

var levelE1Panel = new Ext.Panel({
  id    : 'levelE1Panel',
  name  : 'LevelControl',
  title : 'Level Control Configuration'
});

var backgroundE1Panel = new Ext.Panel({
  id    : 'backgroundE1Panel',
  name  : 'BackgroundNoiseAttenuation',
  title : 'Background Noise Attenuation Configuration'
});

var dtmfE1Panel = new Ext.Panel({
  id    : 'dtmfE1Panel',
  name  : 'DTMFRemoval',
  title : 'DTMF Removal Configuration'
});

/**************************
  Digital E1 Configuration
***************************/
var id_textE1 = new Ext.form.TextField({
  id          : 'id_textE1',
  fieldLabel  : "ID",
  name        : "id",
  disabled    : true,
  width       : 162
});

var name_textE1 = new Ext.form.TextField({
  id          : 'name_textE1',
  fieldLabel  : "Display Name",
  name        : "displayName",
  width       : 162
});

var digitalE1_label = new Ext.form.Label({
  text: "Digital E1 Physical Configuration",
  helpText : "e1ParametersdigitalE1",
  style: 'line-height:40px;'
});

var framingE1_select = new Ext.form.ComboBox({
  id              : 'framingE1_selection',
  name            : 'framing',
  fieldLabel      : "Framing",
  helpText        : "e1ParametersdigitalE1framing",
  store           : ['CRC4','NonCRC4'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

var line_encE1_select = new Ext.form.ComboBox({
  id              : 'line_encE1_selection',
  name            : 'lineEncoding',
  fieldLabel      : "Line Encoding",
  helpText        : "e1ParametersdigitalE1lineEncoding",
  store           : ['AMI','HDB3'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

var clockingE1_select = new Ext.form.ComboBox({
  id              : 'clockingE1_selection',
  name            : 'clocking',
  fieldLabel      : "Clocking",
  helpText        : "clockingclocking",
  store           : ['NETWORK', 'TERMINAL'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

var signalingE1_select = new Ext.form.ComboBox({
  id              : 'signalingE1_selection',
  name            : 'E1Signaling',
  fieldLabel      : "Signaling",
  helpText        : "e1ParametersdigitalE1E1Signaling",
  store           : ['NONE','CCS','CAS'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

var terminationE1_select = new Ext.form.ComboBox({
  id              : 'terminationE1_selection',
  name            : 'E1Termination',
  fieldLabel      : "Termination",
  helpText        : "e1ParametersdigitalE1E1Termination",
  store           : ['75ohm','120ohm'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

/*
var loopback_modeE1_select = new Ext.form.ComboBox({
  id              : 'loopback_modeE1_selection',
  name            : 'loopbackMode',
  fieldLabel      : "Loopback Mode",
  helpText        : "e1ParametersdigitalE1loopbackMode",
  store           : ['DISABLED'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});
*/
var dChannelE1_label = new Ext.form.Label({
  text: "D-Channel E1 Configuration",
  style: 'line-height:40px;'
});

var dChannelE1_disable = new Ext.form.ComboBox({
  id: 'disableDChannelE1',
  fieldLabel: 'Enable/Disable D-Channel',
  name: 'disableDChannel',
  store: ['ENABLED','DISABLED'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

dChannelE1_disable.on('select',isDChannelEnabled,dChannelE1_disable);

// Max value is 31 and Min is 1
var channelE1_idx_text = new Ext.form.TextField({
  id          : 'channelE1_idx_text',
  fieldLabel  : "D-Channel Index",
  name        : "channelIndex",
  helpText    : "e1ParametersdigitalE1DChannelE1channelIndex",
  disabled    : true,
  width       : 162,
  value       : 31
 /* validator  : function(txt){
                 var num = parseInt(txt);
                 if (num < 1) {
                  return "Minimum value for D-Channel index is 1";
                 }
                 if (num > 31) {
                  return "Maximum value for D-Channel index is 31";
                 }
                 return true;
               } */
});

// Max is 4096 and min 256
var mtu_sizeE1_text = new Ext.form.NumberField({
  id          : 'mtu_sizeE1_text',
  fieldLabel  : "MTU Size",
  name        : "mtuSize",
  helpText    : "DChannelMtuSizemtuSize",
  value       : 2048,
  width       : 162
});

mtu_sizeE1_text.on('render',function(){
  isDChannelEnabled.call(dChannelE1_disable);
});

var defaultPcmLawE1_select =  createPcmLawSelection({
  id    : 'defaultPcmLawE1_selection'
});

var voicePacketLengthInMsE1_text = createVoicePacketText({
  id  : 'voicePacketLengthInMsE1_text'
});

var toneSetAttributesE1_select = createToneSetAtributesSelection({
  id  : 'toneSetAttributesE1_select'
});

var ecE1_type_select = createEcTypeSelect({
  id  : 'ecE1_type_selection'
});

var ecE1_mode_select = createEcModeSelect({
  id  : 'ecE1_mode_selection'
});

var ecE1_comfortNoiseMode_select = createEcComfortNoiseSelect({
  id  : 'ecE1_comfortNoiseMode_selection'
});

var ecE1_tailDisplacementInMs_text = createEcTailText({
  id  : 'ecE1_tailDisplacementInMs_text'
});

var ecE1_doubleTalkBehavior_select = createEcDoubleTalkSelect({
  id  : 'ecE1_doubleTalkBehavior_selection'
});

var aecE1_type_select = createAecTypeSelect({
  id  : 'aecE1_type_selection'
});

var aecE1_mode_select = createAecModeSelect({
  id  : 'aecE1_mode_selection'
});

var levelE1_type_select = createLevelTypeSelect({
  id  : 'levelE1_type_selection'
});

var levelE1_direction_select = createLevelDirectionSelect({
  id  : 'levelE1_direction_selection'
});

var levelE1_mode_select = createLevelModeSelect({
  id  : 'levelE1_mode_selection',
  listeners : {
    'select': levelControlVisibleFields,
    scope   : frmDigitalE1PhysConf
//  function(){
//    if( this.getValue() == "AUTOMATIC") {
//      //levelE1_gainIndB_text.hide();
//      //levelE1_gainIndB_text.getEl().up('.x-form-item').setDisplayed(false); //show label
//      levelE1_gainIndB_text.disable();
//      levelE1_gainIndB_text.clearInvalid();
//    } else if( this.getValue() == "MANUAL") {
//      //levelE1_gainIndB_text.show();
//      //levelE1_gainIndB_text.getEl().up('.x-form-item').setDisplayed(true); //show label
//      levelE1_gainIndB_text.enable();
//    }
//  }
  }
});

var levelE1_targetLevelIndBM0_text = createLevelTargetText({
  id  : 'levelE1_targetLevelIndBM0_text'
});

var levelE1_gainIndB_text = createLevelGainText({
  id  : 'levelE1_gainIndB_text'
});

var bnaE1_type_select = createBnaTypeSelect({
  id  : 'bnaE1_type_selection'
});

var bnaE1_direction_select = createBnaDirectionSelect({
  id  : 'bnaE1_direction_selection'
});

var bnaE1_mode_select = createBnaModeSelect({
  id  : 'bnaE1_mode_selection'
});

var bnaE1_attenuationIndB_select = createBnaAttenuationSelect({
  id  : 'bnaE1_attenuationIndB_selection'
});

var dtmfE1_type_select = createDtmfTypeSelect({
  id  : 'dtmfE1_type_selection'
});

var dtmfE1_direction_select = createDtmfDirectionSelect({
  id  : 'dtmfE1_direction_selection'
});

var dtmfE1_mode_select = createDtmfModeSelect({
  id  : 'dtmfE1_mode_selection'
});

e1ConfigPanel.add(id_textE1);
e1ConfigPanel.add(name_textE1);
frmDigitalE1PhysConf.add(e1ConfigPanel);

//frmDigitalE1PhysConf.add(digitalE1_label);
digitalE1Panel.add(framingE1_select);
digitalE1Panel.add(line_encE1_select);
digitalE1Panel.add(clockingE1_select);
digitalE1Panel.add(signalingE1_select);
digitalE1Panel.add(terminationE1_select);
frmDigitalE1PhysConf.add(digitalE1Panel);
//frmDigitalE1PhysConf.add(loopback_modeE1_select);

//frmDigitalE1PhysConf.add(dChannelE1_label);
DChannelE1Panel.add(dChannelE1_disable);
DChannelE1Panel.add(channelE1_idx_text);
DChannelE1Panel.add(mtu_sizeE1_text);
frmDigitalE1PhysConf.add(DChannelE1Panel);

//frmDigitalE1PhysConf.add(createAudioLabel());
audioE1Panel.add(defaultPcmLawE1_select);
audioE1Panel.add(voicePacketLengthInMsE1_text);
audioE1Panel.add(toneSetAttributesE1_select);
frmDigitalE1PhysConf.add(audioE1Panel);

//frmDigitalE1PhysConf.add(createEchoCancelLabel());
echoE1Panel.add(ecE1_type_select);
echoE1Panel.add(ecE1_mode_select);
echoE1Panel.add(ecE1_comfortNoiseMode_select);
echoE1Panel.add(ecE1_tailDisplacementInMs_text);
echoE1Panel.add(ecE1_doubleTalkBehavior_select);
frmDigitalE1PhysConf.add(echoE1Panel);

//frmDigitalE1PhysConf.add(createAcousticLabel());
acousticE1Panel.add(aecE1_type_select);
acousticE1Panel.add(aecE1_mode_select);
frmDigitalE1PhysConf.add(acousticE1Panel);

//frmDigitalE1PhysConf.add(createLevelControlLabel());
levelE1Panel.add(levelE1_type_select);
levelE1Panel.add(levelE1_direction_select);
levelE1Panel.add(levelE1_mode_select);
levelE1Panel.add(levelE1_targetLevelIndBM0_text);
levelE1Panel.add(levelE1_gainIndB_text);
frmDigitalE1PhysConf.add(levelE1Panel);

//frmDigitalE1PhysConf.add(createBackgroundLabel());
backgroundE1Panel.add(bnaE1_type_select);
backgroundE1Panel.add(bnaE1_direction_select);
backgroundE1Panel.add(bnaE1_mode_select);
backgroundE1Panel.add(bnaE1_attenuationIndB_select);
frmDigitalE1PhysConf.add(backgroundE1Panel);

//frmDigitalE1PhysConf.add(createDTMFRemovalLabel());
dtmfE1Panel.add(dtmfE1_type_select);
dtmfE1Panel.add(dtmfE1_direction_select);
dtmfE1Panel.add(dtmfE1_mode_select);
frmDigitalE1PhysConf.add(dtmfE1Panel);


//-----------------------------------------------
// Analog Physical Config form
// -----------------------------------------------
var frmAnalogPhysConf = new Ext.FormPanel({
  title         : "Digital Analog Configuration",
  frame         : true,
  header        : false,
  id            : "frmAnalogPhysConf",
  autoScroll    : true,
  layout        : 'accordion',
  layoutConfig  : {
    activeItem  : 0
  },
  defaults    : {
    layout: 'form',
    style: 'text-align:left;',
    labelWidth: 150,
    bodyStyle: 'padding:5px;',
    width: 500,
    autoHeight: true,
    fill: true
  },
  buttonAlign   : "right",
  buttons       : [{
    text: 'Assigned board(s)',
    listeners: {'click':function(){
        configId = id_textAnalog.getValue();
        unassignedBoardsGrid.getStore().load({
           params: {'id':configId}
        });
        assignedBoardsGrid.getStore().load({
           params: {'id':configId}
        });
        assignBoardsWindow.show();
      }
    }
  },{
    text: 'Save',
    listeners: {'click':saveConfig}
  },{
    text: 'Cancel',
    listeners: {'click':physConfCancel}
  }]
});

var analogConfigPanel = new Ext.Panel({
  id    : 'analogConfigPanel',
  name  : 'config',
  title : 'Configuration Info',
  items : [{
    xtype: 'textfield',
    id: 'analogNodeId',
    name: 'nodeId',
    hidden: true,
    hideLabel: true
  }]
});

var analogPanel = new Ext.Panel({
  id    : 'analogPanel',
  name  : 'analog',
  title : 'Analog Configuration'
});

var audioAnalogPanel = new Ext.Panel({
  id    : 'audioAnalogPanel',
  name  : 'audio',
  title : 'Audio Configuration'
});

var echoAnalogPanel = new Ext.Panel({
  id    : 'echoAnalogPanel',
  name  : 'EchoCancellation',
  title : 'Echo Cancellation Configuration'
});

var acousticAnalogPanel = new Ext.Panel({
  id    : 'acousticAnalogPanel',
  name  : 'AcousticEchoCancellation',
  title : 'Acoustic Echo Cancellation Configuration'
});

var levelAnalogPanel = new Ext.Panel({
  id    : 'levelAnalogPanel',
  name  : 'LevelControl',
  title : 'Level Control Configuration'
});

var backgroundAnalogPanel = new Ext.Panel({
  id    : 'backgroundAnalogPanel',
  name  : 'BackgroundNoiseAttenuation',
  title : 'Background Noise Attenuation Configuration'
});

var dtmfAnalogPanel = new Ext.Panel({
  id    : 'dtmfAnalogPanel',
  name  : 'DTMFRemoval',
  title : 'DTMF Removal Configuration'
});

var id_textAnalog= new Ext.form.TextField({
  id          : 'id_textAnalog',
  fieldLabel  : "ID",
  name        : "id",
  disabled    : true,
  width       : 162
});

var name_textAnalog = new Ext.form.TextField({
  id          : 'name_textAnalog',
  fieldLabel  : "Display Name",
  name        : "displayName",
  width       : 162
});

var analogVariant_select = new Ext.form.ComboBox({
  id              : 'analogVariant_selection',
  name            : 'variant',
  fieldLabel      : "Analog Variant",
  store           : ['Canada','FCC','TBR21','USA'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145
});

var defaultPcmLawAnalog_select =  createPcmLawSelection({
  id    : 'defaultPcmLawAnalog_selection'
});

var voicePacketLengthInMsAnalog_text = createVoicePacketText({
  id  : 'voicePacketLengthInMsAnalog_text'
});

var toneSetAttributesAnalog_select = createToneSetAtributesSelection({
  id  : 'toneSetAttributesAnalog_select'
});

var ecAnalog_type_select = createEcTypeSelect({
  id  : 'ecAnalog_type_selection'
});

var ecAnalog_mode_select = createEcModeSelect({
  id  : 'ecAnalog_mode_selection'
});

var ecAnalog_comfortNoiseMode_select = createEcComfortNoiseSelect({
  id  : 'ecAnalog_comfortNoiseMode_selection'
});

var ecAnalog_tailDisplacementInMs_text = createEcTailText({
  id  : 'ecAnalog_tailDisplacementInMs_text'
});

var ecAnalog_doubleTalkBehavior_select = createEcDoubleTalkSelect({
  id  : 'ecAnalog_doubleTalkBehavior_selection'
});

var aecAnalog_type_select = createAecTypeSelect({
  id  : 'aecAnalog_type_selection'
});

var aecAnalog_mode_select = createAecModeSelect({
  id  : 'aecAnalog_mode_selection'
});

var levelAnalog_type_select = createLevelTypeSelect({
  id  : 'levelAnalog_type_selection'
});

var levelAnalog_direction_select = createLevelDirectionSelect({
  id  : 'levelAnalog_direction_selection'
});

var levelAnalog_mode_select = createLevelModeSelect({
  id  : 'levelAnalog_mode_selection',
  listeners : {
    'select': levelControlVisibleFields,
    scope   : frmAnalogPhysConf
//  function(){
//    if( this.getValue() == "AUTOMATIC") {
//      //levelAnalog_gainIndB_text.hide();
//      //levelAnalog_gainIndB_text.getEl().up('.x-form-item').setDisplayed(false); //show label
//      levelAnalog_gainIndB_text.disable();
//      levelAnalog_gainIndB_text.clearInvalid();
//    } else if( this.getValue() == "MANUAL") {
//      //levelAnalog_gainIndB_text.show();
//      //levelAnalog_gainIndB_text.getEl().up('.x-form-item').setDisplayed(true); //show label
//      levelAnalog_gainIndB_text.enable();
//    }
//  }
  }
});

var levelAnalog_targetLevelIndBM0_text = createLevelTargetText({
  id  : 'levelAnalog_targetLevelIndBM0_text'
});

var levelAnalog_gainIndB_text = createLevelGainText({
  id  : 'levelAnalog_gainIndB_text'
});

var bnaAnalog_type_select = createBnaTypeSelect({
  id  : 'bnaAnalog_type_selection'
});

var bnaAnalog_direction_select = createBnaDirectionSelect({
  id  : 'bnaAnalog_direction_selection'
});

var bnaAnalog_mode_select = createBnaModeSelect({
  id  : 'bnaAnalog_mode_selection'
});

var bnaAnalog_attenuationIndB_select = createBnaAttenuationSelect({
  id  : 'bnaAnalog_attenuationIndB_selection'
});

var dtmfAnalog_type_select = createDtmfTypeSelect({
  id  : 'dtmfAnalog_type_selection'
});

var dtmfAnalog_direction_select = createDtmfDirectionSelect({
  id  : 'dtmfAnalog_direction_selection'
});

var dtmfAnalog_mode_select = createDtmfModeSelect({
  id  : 'dtmfAnalog_mode_selection'
});

analogConfigPanel.add(id_textAnalog);
analogConfigPanel.add(name_textAnalog);
frmAnalogPhysConf.add(analogConfigPanel);

analogPanel.add(analogVariant_select);
frmAnalogPhysConf.add(analogPanel);

//frmAnalogPhysConf.add(createAudioLabel());
audioAnalogPanel.add(defaultPcmLawAnalog_select);
audioAnalogPanel.add(voicePacketLengthInMsAnalog_text);
audioAnalogPanel.add(toneSetAttributesAnalog_select);
frmAnalogPhysConf.add(audioAnalogPanel);

//frmAnalogPhysConf.add(createEchoCancelLabel());
echoAnalogPanel.add(ecAnalog_type_select);
echoAnalogPanel.add(ecAnalog_mode_select);
echoAnalogPanel.add(ecAnalog_comfortNoiseMode_select);
echoAnalogPanel.add(ecAnalog_tailDisplacementInMs_text);
echoAnalogPanel.add(ecAnalog_doubleTalkBehavior_select);
frmAnalogPhysConf.add(echoAnalogPanel);

//frmAnalogPhysConf.add(createAcousticLabel());
acousticAnalogPanel.add(aecAnalog_type_select);
acousticAnalogPanel.add(aecAnalog_mode_select);
frmAnalogPhysConf.add(acousticAnalogPanel);

//frmAnalogPhysConf.add(createLevelControlLabel());
levelAnalogPanel.add(levelAnalog_type_select);
levelAnalogPanel.add(levelAnalog_direction_select);
levelAnalogPanel.add(levelAnalog_mode_select);
levelAnalogPanel.add(levelAnalog_targetLevelIndBM0_text);
levelAnalogPanel.add(levelAnalog_gainIndB_text);
frmAnalogPhysConf.add(levelAnalogPanel);

//frmAnalogPhysConf.add(createBackgroundLabel());
backgroundAnalogPanel.add(bnaAnalog_type_select);
backgroundAnalogPanel.add(bnaAnalog_direction_select);
backgroundAnalogPanel.add(bnaAnalog_mode_select);
backgroundAnalogPanel.add(bnaAnalog_attenuationIndB_select);
frmAnalogPhysConf.add(backgroundAnalogPanel);

//frmAnalogPhysConf.add(createDTMFRemovalLabel());
dtmfAnalogPanel.add(dtmfAnalog_type_select);
dtmfAnalogPanel.add(dtmfAnalog_direction_select);
dtmfAnalogPanel.add(dtmfAnalog_mode_select);
frmAnalogPhysConf.add(dtmfAnalogPanel);

