function beforeSubmit() {
  return hardware_form.findById('board_display').getStore().getRange();
};

function afterSubmit() {
  Paraxip.console.debug('Done submitting configuration');
  hardware_form.findById('board_display').getStore().removeAll();
  navHandler('next');

  var mainTab = Ext.getCmp('mainTabPanel');
  mainTab.setActiveTab("statusControlTabId");

  var editorTab = mainTab.findById("pstnEditorTabId");

  editorTab.setDisabled(false);

  //get the treePanel
  if (editorTab.rendered) {
    var tree = editorTab.findById("tree-panel");
    reloadTree(false);
  }

  Ext.Msg.confirm("Configuration saved!", "Changes will be effective on next gateway startup. Do you want to start the gateway now?",
          restartGatewayHandler);
};

/*
 * Calls the restartGateway method of the status controller in the backend
 * if the user chose yes after the quick setup.
 * @param choice: yes if the user clicked on yes in the confirm message; 
 * 								no if the user clicked on no.
 */
function restartGatewayHandler(choice){
	if( choice == "yes" ) {
		Paraxip.changeGwStatusBar(Paraxip.workingStatus, true, true);
		Paraxip.showProgressBar("Restarting the gateway...");
		Ext.Ajax.request({
			url: 'status/restartGateway',
			method: 'POST',
			disableCaching: true,
			params: {js:Ext.util.JSON.encode('dummy param')},
			success: function(result){
				response = Ext.util.JSON.decode(result.responseText);
				if( response.success ) {
					afterRestart('',"Gateway Started!");
				} else { 
					afterRestart("Unable to start the gateway","The gateway failed to start.\n\nPlease be sure there is a valid configuration file before launching the gateway. This can be accomplished by running the Quick Setup");
				}
			},
			failure: function(){
				 afterRestart();
				 Paraxip.failureMessage();
      }
    });
  }

};

/*
 * Hide the progress bar, force a check on the gateway status to update 
 * the start/stop buttons and the status bar. Can take the title and the 
 * message to show the user in a pop-up window. If the message is null,
 * we show nothing.
 * @param title: the title of the window to display. 
 * @param msg: the message text; null if no window should be shown.
 */
function afterRestart(title, msg){
	Paraxip.hideProgressBar();
	Paraxip.mainTabPanel.isGwStartedCall();
	if( msg != null) {
		Ext.Msg.alert(title,msg);
	}
};

/*
 * Called when the user has finished the quick setup. This method posts
 * the values chosen by the user to the backend server.
 */
function finishHandler() {
  var form = wizard.getForm();
  var el = form.getEl();

  el.dom.action = 'wizard/save';
  el.dom.method = 'POST';
  var records = beforeSubmit();
  var physicalConfig = Ext.util.JSON.encode(form.getValues(false)) ;
  var boardConfigs = new Array();
  for (var i = 0; i < records.length; i++) {
    boardConfigs.push(records[i].data);
  }
  boardConfigs = Ext.util.JSON.encode(boardConfigs);
  form.submit({
    params:{
      'boardConfigs'  : boardConfigs,
      'physicalConfig': physicalConfig
    },
    success: afterSubmit,
    failure: Paraxip.failureMessage
  });
};

/**
 * 
 * This method determines wich form to show to the user in the wizard
 * depending on the direction and the types of boards in the grid.
 * @param direction: helps to know wich form to show; ('next' or 'back')
 * 
 */
var navHandler = function(direction) {

  var lay = wizard.getLayout();

  var active_id = lay.activeItem.id;

  var active_item;

  var show_back = true;
  var last_form = false;
  var boardGrid = hardware_form.getComponent('board_display');
  var hasAnalog = Paraxip.gridHasAnalogBoard(boardGrid);
  var hasDigital = Paraxip.gridHasDigitalBoard(boardGrid);
  var hasVirtualDigital = Paraxip.gridHasVirtualDigitalBoard(boardGrid);

  //Determine witch form to render_next
  if (direction == "next") { //Go forward
    switch (active_id) {
      case "front_form":
        active_item = "hardware_form";
        break;
      case "hardware_form":
        if (hasAnalog) {
          active_item = "analog_form";
        } else if (hasDigital) {
          active_item = "isdn_form";
        } else if (hasVirtualDigital) {
          active_item = "sip_form";
          last_form = true;
        } else {
          Ext.Msg.alert('No board', 'Please add a board to continue');
          active_item = "hardware_form";          
        }
        break;
      case "analog_form":
        if (hasDigital) {
          active_item = "isdn_form";
        } else {
          active_item = "sip_form";
          last_form = true;
        }
        break;
      case "isdn_form":
        active_item = "sip_form";
        last_form = true;
        break;
      case "sip_form":
        active_item = "front_form";
        show_back = false;
        break;
      default:
        active_item = "front_form";
        show_back = false;
        break;
    }
  } else if (direction == "back") { //go backward
    switch (active_id) {
      case "analog_form":
        active_item = "hardware_form";        
        break;
      case "isdn_form":
        if (hasAnalog) {
          active_item = "analog_form";
        } else {
          active_item = "hardware_form";         
        }
        break;
      case "sip_form":
        if (hasDigital) {
          active_item = "isdn_form";
        } else if( hasAnalog ) {
          active_item = "analog_form";
        } else {
          active_item = "hardware_form";          
        }
        break;
      default: // hardware form
        active_item = "front_form";
        show_back = false;
        break;
    }
  }

  lay.setActiveItem(active_item);
  lay.container.setTitle(lay.activeItem.title);

  Ext.getCmp('move-prev').setVisible(show_back);

  if (last_form) {
    next_button.setVisible(false);
    finish_button.setVisible(true);
  } else {
    next_button.setVisible(true);
    finish_button.setVisible(false);
  }
};

var back_button = new Ext.Button({
  id: 'move-prev',
  text: 'Back',
  hidden: true
});

back_button.on('click', navHandler.createDelegate(back_button, ['back']));

var next_button = new Ext.Button({
  id: 'move-next',
  text: 'Next'
});

next_button.on('click', navHandler.createDelegate(next_button, ['next']));

var finish_button = new Ext.Button({
  id: 'finish',
  text: 'Finish',
  hidden: true
});

finish_button.on('click', finishHandler.createDelegate(finish_button));

var wizard = new Ext.FormPanel({
  title       : 'Wizard',
  id          : 'wizard',
  layout      : 'card',
  layoutConfig : {
    deferedRender: true,
    layoutOnTabChange: true
  },
  defaults    : {
    // applied to each contained panel
    border    : false
  },
  // just an example of one possible navigation scheme, using buttons
  bbar: [
    back_button,
    '->',
    next_button,
    finish_button
  ]
});

var isRendered = false; //keep trace of the first render done by doLayout()

wizard.add(hardware_form);
wizard.add(isdn_form);
wizard.add(sip_form);
wizard.add(analog_form);
wizard.add(front_form);

wizard.on('afterlayout', function() {
  if (!isRendered) {
    wizard.setTitle(front_form.title);
    isRendered = true;
  } else if (wizard.getLayout().activeItem === null) {
    wizard.getLayout().setActiveItem(front_form);
  }
});


